// LocalNode.java
// $Id: LocalNode.java,v 1.3 2000/12/15 12:40:30 bmahe Exp $
// (c) COPYRIGHT MIT, INRIA and Keio, 2000.
// Please first read the full copyright statement in file COPYRIGHT.html

package org.w3c.jwput.gui.webdav;

import java.io.*;
import java.util.*;

import javax.swing.*;
import javax.swing.tree.*;

import org.w3c.util.*;

/**
 * @version $Revision: 1.3 $
 * @author  Benot Mah (bmahe@w3.org)
 */
public class LocalNode extends DefaultMutableTreeNode 
    implements DataNode
{

    protected File        directory    = null;    
    protected LocalNode   parent       = null;
    protected LocalNode[] children     = null;
    protected long        lastmodified = -1;
    protected String      name         = null;
    protected FileData    data         = null;

    public void acquireChildren() {
	if (lastmodified < directory.lastModified()) {
	    Vector infos = new Vector();
	    File[] files = directory.listFiles();
	    if (files == null) {
		files = new File[0];
	    }
	    int len = files.length;
	    for (int i = 0 ; i < len ; i++) { 
		File    file       = files[i];
		boolean collection = file.isDirectory();
		String  display    = null;
		if (collection) {
		    display = "Collection";
		} else {
		    display = "Local File";
		}
		FileData fdata = new FileData(file.lastModified(),
					      file.length(),
					      collection,
					      false,
					      file.getName(),
					      display,
					      "",
					      null);
		if (collection) {
		    LocalNode node = new LocalNode(files[i], this);
		    node.data = fdata;
		    fdata.setNode(node);
		    insert(node, 0);
		}
		// else {
		infos.addElement(fdata);
		// }
	    }
	    lastmodified = directory.lastModified();
	    updateData(infos);
	}
    }

    // FileDescription 
    public FileData getFileData() {
	return data;
    }

    protected void updateData(Vector infos) {
	data = new FileData(directory.lastModified(),
			    directory.length(),
			    true,
			    false,
			    directory.getName(),
			    "Collection",
			    "",
			    infos);
	data.setNode(this);
    }

    /**
     * Returns true if the receiver is a leaf.
     * @return a boolean
     */ 
    public boolean isLeaf() {
	return false;
    }

    public String toString() {
	if (name != null) {
	    return name;
	}
	return directory.getName();
    }

    public boolean equals(TreeNode node) {
	if (node instanceof LocalNode) {
	    return directory.equals(((LocalNode)node).directory);
	}
	return false;
    }

    public LocalNode(File directory, LocalNode parent) {
	this(directory, (String)null);
	this.parent = parent;
    }

    public LocalNode(File directory, String name) {
	this.directory = directory;
	this.name      = name;
	if (! directory.isDirectory()) {
	    throw new RuntimeException(directory.getAbsolutePath()+
				       " is not a directory.");
	}
    }

}
